@@ -178,24 +178,9 @@ class Instance(Model):
             **kwargs,
         )
         try:
-            if sys.version_info >= (3, 7):
-                if sys.platform == "win32":
-                    asyncio.set_event_loop_policy(
-                        asyncio.WindowsProactorEventLoopPolicy()
-                    )
-                return asyncio.run(coroutine)
-            else:
-                if sys.platform == "win32":
-                    loop = asyncio.ProactorEventLoop()
-                else:
-                    loop = asyncio.events.new_event_loop()
-
-                try:
-                    asyncio.events.set_event_loop(loop)
-                    return loop.run_until_complete(coroutine)
-                finally:
-                    asyncio.events.set_event_loop(None)
-                    loop.close()
+            if sys.platform == "win32":
+                asyncio.set_event_loop_policy(asyncio.WindowsProactorEventLoopPolicy())
+            return asyncio.run(coroutine)
         except RuntimeError as r:
             if "called from a running event loop" in r.args[0]:
                 raise RuntimeError(
@@ -515,9 +500,15 @@ class Instance(Model):
                 if isinstance(v, UnknownExpression) or k in data:
                     fragments.append(f"{k} = {v};\n")
                 elif isinstance(v, EnumMeta):
-                    fragments.append(
-                        f"{k} = {{{', '.join([i for i in v.__members__])}}};\n"
-                    )
+                    enumDecl = k + " = {"
+                    first = True
+                    for mem in v.__members__:
+                        if not first:
+                            enumDecl += ", "
+                        enumDecl += "'" + str(mem) + "'"
+                        first = False
+                    enumDecl += "};"
+                    fragments.append(enumDecl)
                 else:
                     data[k] = v
             fragments.extend(inst._code_fragments)
@@ -612,7 +603,7 @@ class Instance(Model):
             self._input_cache[key] = _to_python_type(value)
         old_output = self._output_cache
         self._output_cache = {}
-        for (key, value) in interface["output"].items():
+        for key, value in interface["output"].items():
             self._output_cache[key] = _to_python_type(value)
         if interface.get("has_output_item", True):
             self._output_cache["_output_item"] = str
